@@ -29,21 +29,21 @@
  *
  * Hdy minor version component (e.g. 2 if %HDY_VERSION is 1.2.3)
  */
-#define HDY_MINOR_VERSION              (2)
+#define HDY_MINOR_VERSION              (4)
 
 /**
  * HDY_MICRO_VERSION:
  *
  * Hdy micro version component (e.g. 3 if %HDY_VERSION is 1.2.3)
  */
-#define HDY_MICRO_VERSION              (3)
+#define HDY_MICRO_VERSION              (0)
 
 /**
  * HDY_VERSION
  *
  * Hdy version.
  */
-#define HDY_VERSION                    (1.2.3)
+#define HDY_VERSION                    (1.4.0)
 
 /**
  * HDY_VERSION_S:
@@ -51,7 +51,7 @@
  * Handy version, encoded as a string, useful for printing and
  * concatenation.
  */
-#define HDY_VERSION_S                  "1.2.3"
+#define HDY_VERSION_S                  "1.4.0"
 
 #define HDY_ENCODE_VERSION(major,minor,micro) \
         ((major) << 24 | (minor) << 16 | (micro) << 8)
@@ -90,6 +90,16 @@
  */
 #define HDY_VERSION_1_2 (HDY_ENCODE_VERSION (1, 2, 0))
 
+/**
+ * HDY_VERSION_1_4:
+ *
+ * A macro that evaluates to the 1.4 version of Handy, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 1.4
+ */
+#define HDY_VERSION_1_4 (HDY_ENCODE_VERSION (1, 4, 0))
+
 #ifndef _HDY_EXTERN
 #define _HDY_EXTERN extern
 #endif
@@ -107,11 +117,11 @@
 #endif
 
 #ifndef HDY_VERSION_MAX_ALLOWED
-# define HDY_VERSION_MAX_ALLOWED HDY_VERSION_1_2
+# define HDY_VERSION_MAX_ALLOWED HDY_VERSION_1_4
 #endif
 
 #ifndef HDY_VERSION_MIN_REQUIRED
-# define HDY_VERSION_MIN_REQUIRED HDY_VERSION_1_2
+# define HDY_VERSION_MIN_REQUIRED HDY_VERSION_1_4
 #endif
 
 #define HDY_UNAVAILABLE(major, minor) G_UNAVAILABLE(major, minor) _HDY_EXTERN
@@ -135,3 +145,21 @@
 # define HDY_DEPRECATED_TYPE_IN_1_2
 # define HDY_DEPRECATED_TYPE_IN_1_2_FOR(f)
 #endif
+
+#if HDY_VERSION_MAX_ALLOWED < HDY_VERSION_1_4
+# define HDY_AVAILABLE_IN_1_4 HDY_UNAVAILABLE(1, 4)
+#else
+# define HDY_AVAILABLE_IN_1_4 _HDY_EXTERN
+#endif
+
+#if HDY_VERSION_MIN_REQUIRED >= HDY_VERSION_1_4
+# define HDY_DEPRECATED_IN_1_4             _HDY_DEPRECATED
+# define HDY_DEPRECATED_IN_1_4_FOR(f)      _HDY_DEPRECATED_FOR(f)
+# define HDY_DEPRECATED_TYPE_IN_1_4        _HDY_DEPRECATED_TYPE
+# define HDY_DEPRECATED_TYPE_IN_1_4_FOR(f) _HDY_DEPRECATED_TYPE_FOR(f)
+#else
+# define HDY_DEPRECATED_IN_1_4             _HDY_EXTERN
+# define HDY_DEPRECATED_IN_1_4_FOR(f)      _HDY_EXTERN
+# define HDY_DEPRECATED_TYPE_IN_1_4
+# define HDY_DEPRECATED_TYPE_IN_1_4_FOR(f)
+#endif
